@@ -5,9 +5,11 @@ There's some Python 2.x <-> 3.x compatibility code here.
 Pyro - Python Remote Objects.  Copyright by Irmen de Jong (irmen@razorvine.net).
 """
 
+from __future__ import with_statement
 import sys
+import threading
 
-__all__=["tobytes", "unicode", "unichr", "StringIO","next"]
+__all__=["tobytes", "unicode", "unichr", "StringIO", "next", "AtomicCounter"]
 
 if sys.version_info<(3,0):
     from StringIO import StringIO
@@ -28,3 +30,18 @@ if sys.version_info<(2,6):
         return iterable.next()
 else:
     next=next
+
+
+class AtomicCounter(object):
+    def __init__(self):
+        self.lock = threading.Lock()
+        self.count = 0
+    def reset(self):
+        self.count = 0
+    def incr(self):
+        with self.lock:
+            self.count += 1
+    def value(self):
+        with self.lock:
+            return self.count
+
